#!/usr/bin/perl -w
use zebot;

#sub POE::Kernel::ASSERT_DEFAULT () { 1 }
sub POE::Kernel::ASSERT_PONY () { 1 }
#sub POE::Kernel::ASSERT_EVENTS () { 1 }
sub POE::Kernel::ASSERT_STATES () { 1 }

use POE::Kernel;
use POE::Session;
use Data::Dumper;
use strict;

####### START OF MAIN PROG ################################################
print "load settings\n";
my $toutou = new zebot();
#print("CALLING ZEBOT INIT\n");
$toutou->init();
#$toutou->loadSettings();
#print "load reactions:".$settings{"reactionsfile"}."\n";
#loadReactions($settings{"reactionsfile"}); 
#print "load operations".$settings{"operationsfile"}."\n";
#loadOperations($settings{"operationsfile"}); 
#print "LOAD ACTORS\n";

  #print STREAM "(re)connecting to server\n";
  #print "\nsetting up the irc server handlers\n";
  #$toutou->setircserver();
  #print "\ninitializing modules\n";
  #my $actors = $obj->{"actors"};
  #foreach $i (keys(%{$actors}))
  #{
  #   print("init module: zebot  $i ->".$obj->{"actors"}->{$i}."\n");
  #   $actors->{$i}->init($obj);
  # }#foreach $i (keys(%$obj->sysdata()->{"actors"}))
  # start the endless loop
  #print "\nstarting bot\n";
$poe_kernel->run();
exit 0;
